@@ -11,7 +11,7 @@ CONFIG={  'filename':'~/.config/test/cfg.json',
           'user':'aaa',
           'password':'aaa',
           # ------------------  things for DM ----------
-          'target_frame':'detect',
+          'target_frame':'direct',
           'average':0,
           'threshold':0,
           'blur':0,
@@ -19,10 +19,11 @@ CONFIG={  'filename':'~/.config/test/cfg.json',
           'histogram':False,
           # ----------------------
           'resolution':"640x480",
+          # ------------------ ASTRO speed compensation
+          'x':0,
+          'y':0 ,
           #-----------------------
 #          'camera_on':False,   # quewstionable...
-          'x':640,
-          'y':480 ,
           'interpolation':'None',
           'mintime':0.1,       # normal picture rate
           'videodev':0,
