@@ -216,6 +216,14 @@ def display2(videodev, save = False,
         artdelay=0.05
 
         connection_ok = True
+
+        # ---- bytes per second.  strange looks like 7MB/s
+        BPS = 0
+        BPSlast=0
+        BPStag = dt.datetime.now()
+        FPS = 0
+        FPSlast = 0
+
         while connection_ok: #========================================================
             # read the frame from the camera and send it to the server
             #time.sleep(0.05)
@@ -229,8 +237,11 @@ def display2(videodev, save = False,
                     with timeout(2):
                         while ret_val == 0:
                             for i8 in range(1): # I decimate and remove delay
-                                print("1-", flush=True,end="")
+                                #print("1-", flush=True,end="")
                                 bytex += stream.read(1024*10)
+                                BPS+=len(bytex)/1024
+                                if len(bytex)>0:
+                                    FPS+=1
                                 a = bytex.find(b'\xff\xd8') #frame starting
                                 b = bytex.find(b'\xff\xd9') #frame ending
                                 if a != -1 and b != -1:
@@ -238,15 +249,19 @@ def display2(videodev, save = False,
                                     bytex = bytex[b+2:]
                                     frame = cv2.imdecode(np.frombuffer(jpg, dtype=np.uint8), cv2.IMREAD_COLOR)
                                     ret_val=1
-                                    print("got  Size={:6.0f}kB {} {}".format(
+                                    print("got  Size={:6.0f}kB {:6.0f}kB/s {}fps {} {}".format(
                                         len(bytex)/1024,
+                                        BPSlast,
+                                        FPSlast,
                                         datetime.datetime.now(),
                                         sfilenamea
                                     ) , end="\r")
+
                                 else:
                                     ret_val = 0
-                                    #frame = None
-                                    print("Non  sizE={:6.0f}kB ".format(len(bytex)/1024), end = "\r" )
+                                    # frame = None
+                                    # print("Non  sizE={:6.0f}kB ".format(len(bytex)/1024), end = "\r" )
+                                    # print("Non", end = "\r" )
                 except:
                     print("X... exception - connection lost, ")
                     ret_val = 0
@@ -255,7 +270,14 @@ def display2(videodev, save = False,
                     connection_ok = False
 
 
-                print("-2", flush=True,end="")
+                #print("-2", flush=True,end="")
+                if (dt.datetime.now()-BPStag).total_seconds()>1:
+                    BPStag = dt.datetime.now()
+                    BPSlast=BPS
+                    BPS=0
+                    FPSlast = FPS
+                    FPS=0
+
 
                 #while
 
